@@ -187,7 +187,7 @@ class API:
                 for x in self.device_attributes
                 if x.hilo_attribute == attribute or x.attr == attribute
             ),
-            DeviceAttribute(attribute, HILO_READING_TYPES.get(value_type, ""))
+            DeviceAttribute(attribute, HILO_READING_TYPES.get(value_type, "null"))
             if value_type
             else attribute,
         )
@@ -768,6 +768,8 @@ class API:
             "zigBeeChannel",
             "firmwareVersion",
             "onlineStatus",
+            "lastStatusTime",
+            "disconnected"
         ]
 
         gw = {
@@ -779,6 +781,7 @@ class API:
             "settableAttributes": "",
             "id": 1,
             "identifier": req[0].get("dsn"),
+            "sdi": req[0].get("sdi"),
             "provider": 1,
             "model_number": "EQ000017",
             "sw_version": req[0].get("firmwareVersion"),
